==> org.eclipse.cdt.debug.ui.memory.transport.source_1.2.0.200906161748.jar: org/eclipse/cdt/debug/ui/memory/transport/actions/ImportMemoryAction.java <==
/*******************************************************************************
 * Copyright (c) 2006-2009 Wind River Systems, Inc. and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors:
 *     Ted R Williams (Wind River Systems, Inc.) - initial implementation
 *******************************************************************************/

package org.eclipse.cdt.debug.ui.memory.transport.actions;

import org.eclipse.cdt.debug.ui.memory.transport.ImportMemoryDialog;
import org.eclipse.cdt.debug.ui.memory.transport.MemoryTransportPlugin;
import org.eclipse.debug.core.model.IMemoryBlock;
import org.eclipse.debug.internal.ui.views.memory.MemoryView;
import org.eclipse.debug.ui.memory.IMemoryRendering;
import org.eclipse.debug.ui.memory.IMemoryRenderingSite;
import org.eclipse.jface.action.IAction;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.ui.IViewActionDelegate;
import org.eclipse.ui.IViewPart;

/**
 * Action for downloading memory.
 */
public class ImportMemoryAction implements IViewActionDelegate {


	private IMemoryRenderingSite fView;

	public void init(IViewPart view) {
		if (view instanceof IMemoryRenderingSite)
			fView = (IMemoryRenderingSite) view;
	}
	
	private IMemoryBlock getMemoryBlock(ISelection selection)
	{
		IMemoryBlock memBlock = null;
		
		if (selection instanceof IStructuredSelection) {
			IStructuredSelection strucSel = (IStructuredSelection) selection;

			// return if current selection is empty
			if (strucSel.isEmpty())
				return null;

			Object obj = strucSel.getFirstElement();

			if (obj == null)
				return null;

			if (obj instanceof IMemoryRendering) {
				memBlock = ((IMemoryRendering) obj).getMemoryBlock();
			} else if (obj instanceof IMemoryBlock) {
				memBlock = (IMemoryBlock) obj;
			}
		}
		return memBlock;
	}

	public void run(IAction action) {

		ISelection selection = fView.getSite().getSelectionProvider()
				.getSelection();
		IMemoryBlock memBlock = getMemoryBlock(selection);
		if(memBlock == null)
			return;
			
		ImportMemoryDialog dialog = new ImportMemoryDialog(MemoryTransportPlugin.getShell(), memBlock, fView);
		dialog.open();
		
		dialog.getResult();
	}
	
	public void selectionChanged(IAction action, ISelection selection) {
		action.setEnabled(getMemoryBlock(selection) != null);
	}

}

==> org.eclipse.cdt.debug.ui.memory.transport.source_2.3.500.202512020204.jar: org/eclipse/cdt/debug/ui/memory/transport/actions/ImportMemoryAction.java <==
/*******************************************************************************
 * Copyright (c) 2006-2009 Wind River Systems, Inc. and others.
 *
 * This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License 2.0
 * which accompanies this distribution, and is available at
 * https://www.eclipse.org/legal/epl-2.0/
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Contributors:
 *     Ted R Williams (Wind River Systems, Inc.) - initial implementation
 *******************************************************************************/

package org.eclipse.cdt.debug.ui.memory.transport.actions;

import org.eclipse.cdt.debug.ui.memory.transport.ImportMemoryDialog;
import org.eclipse.cdt.debug.ui.memory.transport.MemoryTransportPlugin;
import org.eclipse.debug.ui.memory.IMemoryRenderingSite;
import org.eclipse.jface.action.IAction;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.ui.IViewActionDelegate;
import org.eclipse.ui.IViewPart;

/**
 * Action for downloading memory.
 */
public class ImportMemoryAction implements IViewActionDelegate {

	private IMemoryRenderingSite fView;

	@Override
	public void init(IViewPart view) {
		if (view instanceof IMemoryRenderingSite)
			fView = (IMemoryRenderingSite) view;
	}

	@Override
	public void run(IAction action) {

		ISelection selection = fView.getSite().getSelectionProvider().getSelection();

		// use utility function in export code
		ExportMemoryAction.BlockAndAddress blockAndAddr = ExportMemoryAction
				.getMemoryBlockAndInitialStartAddress(selection);
		if (blockAndAddr.block == null)
			return;

		ImportMemoryDialog dialog = new ImportMemoryDialog(MemoryTransportPlugin.getShell(), blockAndAddr.block,
				blockAndAddr.addr, fView);
		dialog.open();

		dialog.getResult();
	}

	@Override
	public void selectionChanged(IAction action, ISelection selection) {
		// use utility function in export code
		action.setEnabled(ExportMemoryAction.getMemoryBlockAndInitialStartAddress(selection).block != null);
	}

}
